@@ -6,6 +6,17 @@ from mongoengine.fields import (Document, StringField, DateTimeField,
                                 DictField, FloatField, EmbeddedDocumentField)
 
 
+class VelocityKPI(EmbeddedDocument):
+    """The velocity KPI total and sub-totals."""
+
+    pr_size = FloatField(default=0.0)
+    pr_duration = FloatField(default=0.0)
+    pr_commit_count = FloatField(default=0.0)
+    commit_freq = FloatField(default=0.0)
+    comment_percent = FloatField()
+    space_percent = FloatField()
+
+
 class RepoEvents(Document):
     """The repository events collection model.
 
@@ -19,7 +30,7 @@ class RepoEvents(Document):
     meta = {'allow_inheritance': True}
 
     # Static list of valid event types
-    valid_event_types = ("ReleaseEvent", "CommitEvent", "PullEvent")
+    valid_event_types = ("UserEvent", "CommitEvent")
 
     # Crawler fields
     event_type = StringField(required=True, choices=valid_event_types)
@@ -27,6 +38,26 @@ class RepoEvents(Document):
     repository = StringField(required=True)
     timestamp = DateTimeField(required=True)
 
+    # Commit fields
+    sha = StringField(required=True)
+    ref = StringField(required=True, null=True)
+    user = StringField(required=True)
+
+    # PR Details
+    additions = IntField(default=0)
+    deletions = IntField(default=0)
+    total = IntField(default=0)
+    commit_files = ListField()
+    velocity_kpi = EmbeddedDocumentField(VelocityKPI)
+
+    # Category and Tokens
+    repo_type = StringField()
+    category = DictField()
+    file_count = DictField()
+    tokens = DictField()
+    files = ListField()
+
+
 class LinterScanEvent(EmbeddedDocument):
     """A sub-document for static analysis events.
 
@@ -43,33 +74,6 @@ class LinterScanEvent(EmbeddedDocument):
     warnings_total = IntField()
     linter_output = StringField()
 
-    def __init__(self, **kwargs):
-        """Pass any init parameters to the Document class."""
-        EmbeddedDocument.__init__(self, **kwargs)
-
-
-class ReleaseEvent(RepoEvents):
-    """The GitHub release events model."""
-    def __init__(self, **kwargs):
-        RepoEvents.__init__(self, **kwargs)
-        self.event_type = "ReleaseEvent"
-
-
-class PullEvent(RepoEvents):
-    """The GitHub pull requests events model."""
-
-    sha = StringField(required=True)
-    ref = StringField(required=True, null=True)
-
-    merged = BooleanField(required=True)
-    commits = IntField(required=True)
-    additions = IntField(required=True)
-    deletions = IntField(required=True)
-    changed_files = IntField(required=True)
-
-    def __init__(self, **kwargs):
-        RepoEvents.__init__(self, **kwargs)
-        self.event_type = "PullEvent"
 
 class MaturityKPI(EmbeddedDocument):
     """The maturity KPI total and sub-totals."""
@@ -80,16 +84,17 @@ class MaturityKPI(EmbeddedDocument):
     automation = FloatField(default=0.0)
     security = FloatField(default=0.0)
 
-    def __init__(self, load_dict, **kwargs):
+    def __init__(self, load_dict=None, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
         self.load(load_dict)
 
     def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.assets = load_dict["assets"]
-        self.tooling = load_dict["tooling"]
-        self.automation = load_dict["automation"]
-        self.security = load_dict["security"]
+        if load_dict:
+            self.total = load_dict["total"]
+            self.assets = load_dict["assets"]
+            self.tooling = load_dict["tooling"]
+            self.automation = load_dict["automation"]
+            self.security = load_dict["security"]
 
 
 class QualityKPI(EmbeddedDocument):
@@ -101,16 +106,17 @@ class QualityKPI(EmbeddedDocument):
     static_analyis = FloatField(default=0.0)
     deploy = FloatField(default=0.0)
 
-    def __init__(self, load_dict, **kwargs):
+    def __init__(self, load_dict=None, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
         self.load(load_dict)
 
     def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.pipeline = load_dict["pipeline"]
-        self.testing = load_dict["testing"]
-        self.static_analysis = load_dict["static_analysis"]
-        self.deploy = load_dict["deploy"]
+        if load_dict:
+            self.total = load_dict["total"]
+            self.pipeline = load_dict["pipeline"]
+            self.testing = load_dict["testing"]
+            self.static_analysis = load_dict["static_analysis"]
+            self.deploy = load_dict["deploy"]
 
 
 class RiskKPI(EmbeddedDocument):
@@ -121,22 +127,23 @@ class RiskKPI(EmbeddedDocument):
     auth = FloatField(default=0.0)
     keys = FloatField(default=0.0)
     compliance = FloatField(default=0.0)
-    delta_warning = FloatField(default=0.0) 
-    delta_errors = FloatField(default=0.0) 
+    code_warnings = FloatField(default=0.0)
+    code_errors = FloatField(default=0.0)
     devops_warnings = FloatField(default=0.0)
     devops_errors = FloatField(default=0.0)
 
-
-    def __init__(self, load_dict, **kwargs):
+    def __init__(self, load_dict=None, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
         self.load(load_dict)
 
     def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.secrets = load_dict["secrets"]
-        self.auth = load_dict["auth"]
-        self.keys = load_dict["keys"]
-        self.compliance = load_dict["compliance"]
+        if load_dict:
+            self.total = load_dict["total"]
+            self.secrets = load_dict["secrets"]
+            self.auth = load_dict["auth"]
+            self.keys = load_dict["keys"]
+            self.compliance = load_dict["compliance"]
+
 
 class InfrastructureKPI(EmbeddedDocument):
     """The infrastructure KPI total and sub-totals."""
@@ -147,27 +154,17 @@ class InfrastructureKPI(EmbeddedDocument):
     compute_resources = FloatField(default=0.0)
     environments = FloatField(default=0.0)
 
-    def __init__(self, load_dict, **kwargs):
+    def __init__(self, load_dict=None, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
         self.load(load_dict)
 
     def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.tags = load_dict["tags"]
-        self.networking = load_dict["networking"]
-        self.compute_resources = load_dict["compute_resources"]
-        self.environments = load_dict["environments"]
-
-class VelocityKPI(EmbeddedDocument):
-    """The velocity KPI total and sub-totals."""
-
-    pr_size = FloatField(default=0.0)
-    pr_duration = FloatField(default=0.0)
-    pr_commit_count = FloatField(default=0.0)
-    commit_freq = FloatField(default=0.0)
-    actors = ListField()
-    comment_percent = FloatField()
-    space_percent = FloatField()
+        if load_dict:
+            self.total = load_dict["total"]
+            self.tags = load_dict["tags"]
+            self.networking = load_dict["networking"]
+            self.compute_resources = load_dict["compute_resources"]
+            self.environments = load_dict["environments"]
 
 
 class InvestmentKPI(EmbeddedDocument):
@@ -179,16 +176,28 @@ class InvestmentKPI(EmbeddedDocument):
     devops = FloatField(default=0.0)
     debt = FloatField(default=0.0)
 
-    def __init__(self, load_dict, **kwargs):
+    def __init__(self, load_dict=None, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
         self.load(load_dict)
 
     def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.features = load_dict["features"]
-        self.defects = load_dict["defects"]
-        self.devops = load_dict["devops"]
-        self.debt = load_dict["debt"]
+        if load_dict:
+            self.total = load_dict["total"]
+            self.features = load_dict["features"]
+            self.defects = load_dict["defects"]
+            self.devops = load_dict["devops"]
+            self.debt = load_dict["debt"]
+
+
+class UserCommit(EmbeddedDocument):
+    ''' User Commit '''
+    user = StringField(required=True)
+    sha = StringField(required=True)
+
+
+class UserEvent(RepoEvents):
+    """The GitHub pull requests events model."""
+
 
 class CommitEvent(RepoEvents):
     """The GitHub commit events model.
@@ -201,18 +210,8 @@ class CommitEvent(RepoEvents):
         LinterScanEvents (Document): A sub-document for static analysis events.
     """
 
-    # Commit fields
-    sha = StringField(required=True)
-    additions = IntField(default=0)
-    deletions = IntField(default=0)
-    total = IntField(default=0)
-    commit_files = ListField()
-
-    # Category and Tokens
-    category =  DictField()
-    file_count = DictField()
-    #tokens = DictField()
-    #files = ListField()
+    # User Contributions
+    users_commits = ListField(UserCommit)
 
     # Linter fields
     linter_events = EmbeddedDocumentListField(LinterScanEvent)
@@ -222,58 +221,59 @@ class CommitEvent(RepoEvents):
     maturity_kpi = EmbeddedDocumentField(MaturityKPI)
     quality_kpi = EmbeddedDocumentField(QualityKPI)
     risk_kpi = EmbeddedDocumentField(RiskKPI)
-    velocity_kpi = EmbeddedDocumentField(VelocityKPI)
     infra_kpi = EmbeddedDocumentField(InfrastructureKPI)
 
-    def __init__(self, **kwargs):
-        RepoEvents.__init__(self, **kwargs)
-        self.event_type = "CommitEvent"
 
 class PipelineRun(Document):
     name = StringField(max_length=120, required=True)
     number = IntField()
     repo = StringField(max_length=200)
     branch = StringField(max_length=50)
+    sha = StringField(max_length=50)
+    commit_id = StringField(max_length=50)
+
+    build_files = ListField(StringField(max_length=128))
+    file_count = IntField()
+
     buildnumber = IntField(required=True)
     building = BooleanField(required=True)
-    durationMillis = IntField()
+    duration_millis = IntField()
     result = StringField(max_length=50)
     timestamp = DateTimeField()
     url = StringField(max_length=256)
+
     fail_stage = StringField(max_length=50)
     fail_logs = StringField(max_length=10000)
-    tags = ListField(StringField(max_length=30))
-    meta = {
-        'indexes': [
-            'name'
-        ]}
+
 
 class Group(Document):
     name = StringField(max_length=120, primary_key=True, required=True)
     children = ListField(StringField(max_length=120))
 
+
 class Set(Document):
     name = StringField(max_length=120, primary_key=True, required=True)
     children = ListField(StringField(max_length=120))
 
+
 class JiraIssue(Document):
-    issue_id            = StringField()
-    issue_key           = StringField()
-    issuetype_name      = StringField()
-    parent_issue_key    = StringField()
-    parent_issue_id     = StringField()
-    project_id          = StringField()
-    project_key         = StringField()
-    project_name        = StringField()
-    resolution_name     = StringField()
-    resolution_date     = DateTimeField()
-    created             = DateTimeField()
-    priority_name       = StringField()
-    priority_id         = StringField()
-    status_name         = StringField()
-    assignee_key        = StringField()
-    story_points        = FloatField()
-    labels              = ListField(StringField())
-    work_begin_date     = DateTimeField()
+    issue_id = StringField()
+    issue_key = StringField(primary_key=True, required=True)
+    issuetype_name = StringField()
+    parent_issue_key = StringField()
+    parent_issue_id = StringField()
+    project_id = StringField()
+    project_key = StringField()
+    project_name = StringField()
+    resolution_name = StringField()
+    resolution_date = DateTimeField()
+    created = DateTimeField()
+    priority_name = StringField()
+    priority_id = StringField()
+    status_name = StringField()
+    assignee_key = StringField()
+    story_points = FloatField()
+    labels = ListField(StringField())
+    updated = DateTimeField()
+    work_begin_date = DateTimeField()
     work_completed_date = DateTimeField()
-    
\ No newline at end of file
